xlwings - Make Excel Fly!
=========================

xlwings is a `BSD-licensed <http://opensource.org/licenses/BSD-3-Clause>`_ Python library that makes it easy to call
Python from Excel and vice versa:

* **Scripting**: Automate/interact with Excel from Python using a syntax close to VBA.
* **Macros**: Replace VBA macros with clean and powerful Python code.
* **UDFs**: Write User Defined Functions (UDFs) in Python (Windows only).

**Numpy arrays** and **Pandas Series/DataFrames** are fully supported. xlwings-powered workbooks are easy to distribute and work
on **Windows** and **Mac**.


.. toctree::
    :maxdepth: 2
    :hidden:

    whatsnew
    migrate_to_0.9
    installation
    quickstart
    connect_to_workbook
    syntax_overview
    datastructures
    vba
    debugging
    matplotlib
    udfs
    converters
    command_line
    missing_features
    r_and_julia
    api





